﻿using Infragistics.Win;
using Infragistics.Win.UltraWinGrid;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace WindowsFormsApplication3
{
    public partial class Form1 : Form
    {
        private ValueList severityList = new ValueList();

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            this.ultraGrid1.DisplayLayout.Override.DefaultRowHeight = 23;

            this.bindingSource1.DataSource = DescriptionList;

            this.severityList.ValueListItems.Add(new ValueListItem(1, "Fatal") { Appearance = { Image = CreateColorImage(16, 23, Color.Black) } });
            this.severityList.ValueListItems.Add(new ValueListItem(2, "Critical") { Appearance = { Image = CreateColorImage(16, 23, Color.Red) } });
            this.severityList.ValueListItems.Add(new ValueListItem(3, "Major") { Appearance = { Image = CreateColorImage(16, 23, Color.Orange) } });
        }

        public List<Data> DescriptionList
        {
            get
            {
                return new List<Data>()
                {
                    new Data() { Key = 1, SeverityId = 1, Description = "imperdiet et commodo vulputate justo in blandit ultrices enim lorem ipsum dolor sit amet consectetuer adipiscing elit proin interdum mauris non ligula"},
                    new Data() { Key = 2, SeverityId = 2, Description = "oque penatibus et magnis dis parturient montes nascetur ridiculus mus etiam vel augue vestibulum rutrum rutrum neque aenean auctor gravida sem praesent id massa id nisl venenatis lacinia aenean sit amet justo morbi ut odio cras mi pede"},
                    new Data() { Key = 3, SeverityId = 3, Description = "tortor sollicitudin mi sit amet lobortis sapien sapien non mi integer ac neque duis bibendum morbi non quam nec dui luctus rutrum nulla tellus in sagittis dui vel"},
                    new Data() { Key = 4, SeverityId = 2, Description = "Regel"},
                    new Data() { Key = 5, SeverityId = 1, Description = "Nog een regel"},
                    new Data() { Key = 6, SeverityId = 3, Description = "Alweer een regel"}
                };
            }
        }

        private void ultraGrid1_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {
            var band = e.Layout.Bands[0];

            if (!band.Columns.Exists("Severity"))
            {
                var severityColumn = band.Columns.Add("Severity");
                severityColumn.Style = Infragistics.Win.UltraWinGrid.ColumnStyle.FormattedText;
            }
        }



        public static Image CreateColorImage(int width, int height, Color color)
        {
            var bitmap = new Bitmap(width, height);
            using (var graphics = Graphics.FromImage(bitmap))
            {
                using (var brush = new SolidBrush(color))
                {
                    graphics.FillRectangle(brush, 0, 0, width, height);
                }
            }

            return bitmap;
        }

        private static string GetImageTag(Image image)
        {
            return $"<img style=\"width:{image.Width} height:{image.Height}\" data=\"{Infragistics.Win.FormattedLinkLabel.FormattedLinkEditor.EncodeImage(image)}\"/>";
        }

        private void ultraGrid1_InitializeRow(object sender, InitializeRowEventArgs e)
        {
            int severityId = (int)e.Row.Cells["SeverityID"].Value;
            var severityItem = this.severityList.FindByDataValue(severityId);

            string imageString = GetImageTag(severityItem.Appearance.Image as System.Drawing.Image);

            StringBuilder sb = new StringBuilder();
            sb.Append("<div>");
            sb.Append(imageString);
            sb.Append($"<span style=\"vertical-align:top;\">{severityItem.DisplayText}</span>");
            sb.Append("</div>");

            e.Row.Cells["Severity"].Value = sb.ToString();
        }

        private void button1_Click(object sender, EventArgs e)
        {
            var band = this.ultraGrid1.DisplayLayout.Bands[0];

            this.ultraGrid1.DisplayLayout.Override.RowSizing = RowSizing.AutoFree;
            var column = band.Columns.Cast<UltraGridColumn>().First(f => f.Key == "Description");

            column.CellMultiLine = Infragistics.Win.DefaultableBoolean.True;
        }

        private void button2_Click(object sender, EventArgs e)
        {
            MessageBox.Show(this, "Row height: " + this.ultraGrid1.ActiveRow.Height, string.Empty, MessageBoxButtons.OK);
        }

        private void button3_Click(object sender, EventArgs e)
        {
            var band = this.ultraGrid1.DisplayLayout.Bands[0];

            this.ultraGrid1.DisplayLayout.Override.RowSizing = RowSizing.Default;
            var column = band.Columns.Cast<UltraGridColumn>().First(f => f.Key == "Description");

            column.CellMultiLine = Infragistics.Win.DefaultableBoolean.False;
        }
    }

    public class Data
    {
        public int Key { get; set; }

        public string Description { get; set; }

        public int SeverityId { get; set; }
    }
}
